==> xcsoar-7.19.tar.xz: xcsoar-7.19/src/Engine/Task/Factory/MatTaskFactory.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_MAT_TASK_FACTORY_HPP
#define XCSOAR_MAT_TASK_FACTORY_HPP

#include "AbstractTaskFactory.hpp"

/**
 * Factory for construction of legal Modified Area Tasks
 */
class MatTaskFactory final : public AbstractTaskFactory {
public:
  /**
   * Constructor
   *
   * @param _task Ordered task to be managed by this factory
   * @param tb Behaviour (options)
   */
  MatTaskFactory(OrderedTask &_task, const TaskBehaviour &tb);

  /**
   * converts all intermediate points to AAT Cylinders
   * Leaves starts and finishes unchanged
   * @param tp
   * @return: point type compatible with current factory, most
   * similar to type of tp
   */
  TaskPointFactoryType GetMutatedPointType(const OrderedTaskPoint &tp) const override;
};


#endif

==> xcsoar-7.27.tar.xz: xcsoar-7.27/src/Engine/Task/Factory/MatTaskFactory.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2022 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#pragma once

#include "AbstractTaskFactory.hpp"

/**
 * Factory for construction of legal Modified Area Tasks
 */
class MatTaskFactory final : public AbstractTaskFactory {
public:
  /**
   * Constructor
   *
   * @param _task Ordered task to be managed by this factory
   * @param tb Behaviour (options)
   */
  MatTaskFactory(OrderedTask &_task, const TaskBehaviour &tb) noexcept;

  /**
   * converts all intermediate points to AAT Cylinders
   * Leaves starts and finishes unchanged
   * @param tp
   * @return: point type compatible with current factory, most
   * similar to type of tp
   */
  TaskPointFactoryType GetMutatedPointType(const OrderedTaskPoint &tp) const noexcept override;
};
